@@ -5,6 +5,6 @@ OFFICIAL_OPERATORS = {
     "aws-ec2": "bentoml/aws-ec2-deploy",
     "azure-functions": "bentoml/azure-functions-deploy",
     "azure-container-instances": "bentoml/azure-container-instances-deploy",  # noqa: E501
-    "google-compute-engine": "bentoml/google-compute-engine-deploy:",
-    "google-cloud-run": "bentoml/google-cloud-run-deploy:",
+    "google-compute-engine": "bentoml/google-compute-engine-deploy",
+    "google-cloud-run": "bentoml/google-cloud-run-deploy",
 }
